@@ -11,11 +11,11 @@ Ixchel::DefaultConfig - The default config used for with Ixchel.
 
 =head1 VERSION
 
-Version 0.0.1
+Version 0.1.0
 
 =cut
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.1.0';
 
 =head1 SYNOPSIS
 
@@ -160,6 +160,7 @@ sub get {
 			pkgs_optional   => [],
 			pkgs_always_try => 1,
 			pkgs_require    => [],
+			cpanm_home      => undef,
 		},
 		systemd => {
 			auto     => {},
@@ -235,8 +236,13 @@ sub get {
 			krb5_ccname                   => '',
 			dref                          => '',
 		},
-		sneck => { enable => 0, },
-		snmp  => {
+		sneck => {
+			enable => 0,
+			vars   => {},
+			tests  => {},
+		},
+		env  => {},
+		snmp => {
 			community         => 'public',
 			extend_env        => 'PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin LC_ALL=C',
 			syslocation       => '',
@@ -304,7 +310,7 @@ sub get {
 	if ( $^O eq 'linux' ) {
 		$config->{suricata}{config_base}            = '/etc/suricata';
 		$config->{snmp}{extend_base_dir}            = '/etc/snmp/';
-		$config->{snmp}{config_file}            = '/etc/snmp/snmpd.conf';
+		$config->{snmp}{config_file}                = '/etc/snmp/snmpd.conf';
 		$config->{snmp}{linux_softnet_stat}{enable} = 1;
 
 		#		if ($host_info->{operating_system} eq 'Debian' || $host_info->{operating_system} eq 'Ubuntu') {
